==> gnuastro_0.3.31.orig.tar.gz: gnuastro-0.3.31-8415/lib/gnuastro/config.h <==
/*********************************************************************
Functions dealing with general aspects of all Gnuastro.

Original author:
     Mohammad Akhlaghi <akhlaghi@gnu.org>
Contributing author(s):
Copyright (C) 2016, Free Software Foundation, Inc.

Gnuastro is free software: you can redistribute it and/or modify it
under the terms of the GNU General Public License as published by the
Free Software Foundation, either version 3 of the License, or (at your
option) any later version.

Gnuastro is distributed in the hope that it will be useful, but
WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
General Public License for more details.

You should have received a copy of the GNU General Public License
along with Gnuastro. If not, see <http://www.gnu.org/licenses/>.
**********************************************************************/
#ifndef __GAL_CONFIG_H__
#define __GAL_CONFIG_H__

/* Include other headers if necessary here. Note that other header files
   must be included before the C++ preparations below */


/* The restrict keyword might not be present on some systems, so we are
   redefining it here based on the checks in `configure.ac', see there for
   more comments. */
#define restrict __restrict


/* Configuration macros: */

#define GAL_CONFIG_VERSION              "0.3.31-8415"

#define GAL_CONFIG_HAVE_LIBGIT2         1

#define GAL_CONFIG_HAVE_WCSLIB_VERSION  1

#define GAL_CONFIG_HAVE_PTHREAD_BARRIER 1

#define GAL_CONFIG_BIN_OP_UINT8         1
#define GAL_CONFIG_BIN_OP_INT8          0
#define GAL_CONFIG_BIN_OP_UINT16        0
#define GAL_CONFIG_BIN_OP_INT16         0
#define GAL_CONFIG_BIN_OP_UINT32        0
#define GAL_CONFIG_BIN_OP_INT32         0
#define GAL_CONFIG_BIN_OP_UINT64        1
#define GAL_CONFIG_BIN_OP_INT64         1
#define GAL_CONFIG_BIN_OP_FLOAT32       1
#define GAL_CONFIG_BIN_OP_FLOAT64       1

#define GAL_CONFIG_SIZEOF_LONG          8
#define GAL_CONFIG_SIZEOF_SIZE_T        8


/* C++ Preparations */
#undef __BEGIN_C_DECLS
#undef __END_C_DECLS
#ifdef __cplusplus
# define __BEGIN_C_DECLS extern "C" {
# define __END_C_DECLS }
#else
# define __BEGIN_C_DECLS                /* empty */
# define __END_C_DECLS                  /* empty */
#endif
/* End of C++ preparations */



/* Actual header contants (the above were for the Pre-processor). */
__BEGIN_C_DECLS  /* From C++ preparations */






__END_C_DECLS    /* From C++ preparations */

#endif           /* __GAL_CONFIG_H__ */

==> gnuastro_0.3.55.orig.tar.gz: gnuastro-0.3.55-a8422/lib/gnuastro/config.h <==
/*********************************************************************
Functions dealing with general aspects of all Gnuastro.

Original author:
     Mohammad Akhlaghi <akhlaghi@gnu.org>
Contributing author(s):
Copyright (C) 2016, Free Software Foundation, Inc.

Gnuastro is free software: you can redistribute it and/or modify it
under the terms of the GNU General Public License as published by the
Free Software Foundation, either version 3 of the License, or (at your
option) any later version.

Gnuastro is distributed in the hope that it will be useful, but
WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
General Public License for more details.

You should have received a copy of the GNU General Public License
along with Gnuastro. If not, see <http://www.gnu.org/licenses/>.
**********************************************************************/
#ifndef __GAL_CONFIG_H__
#define __GAL_CONFIG_H__

/* Include other headers if necessary here. Note that other header files
   must be included before the C++ preparations below */


/* The restrict keyword might not be present on some systems, so we are
   redefining it here based on the checks in `configure.ac', see there for
   more comments. */
#define restrict __restrict


/* Configuration macros: */

#define GAL_CONFIG_VERSION              "0.3.55-a8422"

#define GAL_CONFIG_HAVE_LIBGIT2         1

#define GAL_CONFIG_HAVE_WCSLIB_VERSION  1

#define GAL_CONFIG_HAVE_PTHREAD_BARRIER 1

#define GAL_CONFIG_BIN_OP_UINT8         1
#define GAL_CONFIG_BIN_OP_INT8          0
#define GAL_CONFIG_BIN_OP_UINT16        0
#define GAL_CONFIG_BIN_OP_INT16         0
#define GAL_CONFIG_BIN_OP_UINT32        0
#define GAL_CONFIG_BIN_OP_INT32         0
#define GAL_CONFIG_BIN_OP_UINT64        1
#define GAL_CONFIG_BIN_OP_INT64         1
#define GAL_CONFIG_BIN_OP_FLOAT32       1
#define GAL_CONFIG_BIN_OP_FLOAT64       1

#define GAL_CONFIG_SIZEOF_LONG          8
#define GAL_CONFIG_SIZEOF_SIZE_T        8


/* C++ Preparations */
#undef __BEGIN_C_DECLS
#undef __END_C_DECLS
#ifdef __cplusplus
# define __BEGIN_C_DECLS extern "C" {
# define __END_C_DECLS }
#else
# define __BEGIN_C_DECLS                /* empty */
# define __END_C_DECLS                  /* empty */
#endif
/* End of C++ preparations */



/* Actual header contants (the above were for the Pre-processor). */
__BEGIN_C_DECLS  /* From C++ preparations */






__END_C_DECLS    /* From C++ preparations */

#endif           /* __GAL_CONFIG_H__ */
